@@ -1,4 +1,5 @@
 import getpass
+from typing import Union
 
 import click
 
@@ -6,6 +7,23 @@ import releasetool.commands.tag.nodejs
 from releasetool.commands.common import TagContext
 
 
+def kokoro_job_name(upstream_repo: str, package_name: str) -> Union[str, None]:
+    """Return the Kokoro job name.
+
+    Args:
+        upstream_repo (str): The GitHub repo in the form of `<owner>/<repo>`
+        package_name (str): The name of package to release
+
+    Returns:
+        The name of the Kokoro job to trigger or None if there is no job to trigger
+    """
+    return None
+
+
+def package_name(pull: dict) -> Union[str, None]:
+    return None
+
+
 def tag(ctx: TagContext = None) -> TagContext:
     # PHP just needs a release to be tagged on GitHub.
     # Tagging logic is the same as NodeJs.
