@@ -216,6 +216,43 @@ def test_trigger_single(
     update_pull_labels.assert_not_called()
 
 
+@patch("autorelease.trigger.LANGUAGE_ALLOWLIST", ["java"])
+@patch("autorelease.kokoro.make_authorized_session")
+@patch("autorelease.github.GitHub.get_issue")
+@patch("autorelease.github.GitHub.get_url")
+@patch("autorelease.github.GitHub.update_pull_labels")
+@patch("autorelease.kokoro.trigger_build")
+def test_trigger_package(
+    trigger_build, update_pull_labels, get_url, get_issue, make_authorized_session
+):
+    github = Mock()
+    kokoro_session = Mock()
+    github.get_url.return_value = {
+        "merged_at": "2021-01-01T09:00:00.000Z",
+        "base": {"repo": {"full_name": "GoogleCloudPlatform/functions-framework-java"}},
+        "html_url": "https://github.com/GoogleCloudPlatform/functions-framework-java/pull/111",
+        "labels": [{"id": 111, "name": "autorelease: tagged"}],
+        "merge_commit_sha": "abcd111",
+        "title": "chore(master): release java-function-invoker 1.1.2",
+    }
+    issue = {
+        "pull_request": {
+            "url": "https://api.github.com/repos/GoogleCloudPlatform/functions-framework-java/pulls/111"
+        },
+        "merged_at": "2021-01-01T09:00:00.000Z",
+    }
+
+    trigger.trigger_kokoro_build_for_pull_request(kokoro_session, github, issue, Mock())
+    trigger_build.assert_called_with(
+        kokoro_session,
+        job_name="functions-framework/java/java-function-invoker/release",
+        sha="abcd111",
+        env_vars={
+            "AUTORELEASE_PR": "https://github.com/GoogleCloudPlatform/functions-framework-java/pull/111"
+        },
+    )
+
+
 @patch("autorelease.kokoro.make_authorized_session")
 @patch("autorelease.kokoro.trigger_build")
 def test_trigger_single_bad_url(trigger_build, make_authorized_session):
